import { registerCodeBlockRenderer } from ".";
import { SvelteCodeBlockRenderer } from "./SvelteCodeBlockRenderer";
import ShelfCodeBockView from "./ShelfCodeBlockView.svelte";
import type BookTrackerPlugin from "@src/main";
import z from "zod/v4";
import { STATUS_IN_PROGRESS, STATUS_READ, STATUS_TO_BE_READ } from "@src/const";

export function registerShelfCodeBlockProcessor(
	plugin: BookTrackerPlugin
): void {
	registerCodeBlockRenderer(
		plugin,
		"shelf",
		(source, el) =>
			new SvelteCodeBlockRenderer(ShelfCodeBockView, plugin, source, el)
	);
}

export const SHELF_VIEWS = ["table", "bookshelf", "details"] as const;
export type ShelfView = (typeof SHELF_VIEWS)[number];

export const ShelfSettingsSchema = z.object({
	statusFilter: z
		.enum([STATUS_TO_BE_READ, STATUS_IN_PROGRESS, STATUS_READ])
		.default(STATUS_TO_BE_READ),
	defaultView: z.enum(SHELF_VIEWS).default("table"),
});

export type ShelfSettings = z.infer<typeof ShelfSettingsSchema>;
