import { mount, unmount, type Component } from "svelte";
import { MarkdownRenderChild } from "obsidian";
import type BookTrackerPlugin from "@src/main";

export interface SvelteCodeBlockProps {
	plugin: BookTrackerPlugin;
	source: string;
}

export class SvelteCodeBlockRenderer<
	TComponent extends Component<SvelteCodeBlockProps, TExports>,
	TExports extends Record<string, any> = {}
> extends MarkdownRenderChild {
	protected component: TExports | undefined;

	constructor(
		private readonly componentCtor: TComponent,
		private readonly plugin: BookTrackerPlugin,
		private readonly source: string,
		private readonly contentEl: HTMLElement
	) {
		super(contentEl);
	}

	onload(): void {
		this.component = mount(this.componentCtor, {
			target: this.contentEl,
			props: {
				plugin: this.plugin,
				source: this.source,
			},
		});
	}

	onunload(): void {
		if (this.component) {
			unmount(this.component);
			this.component = undefined;
		}
	}
}
